pub trait HdSpi {
// Required methods
async fn read(&mut self, command: HdCommand, addr: u32, buf: &mut [u8]);
async fn write(&mut self, command: HdCommand, addr: u32, buf: &[u8]);
}Expand description
Trait for a half-duplex SPI interface.
The device must be configured to use the same number of data lines as the hosted firmware.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.